@@ -31,7 +31,7 @@ Python library.
 """
 
 # Module version
-__version_info__ = (0, 1, 1)
+__version_info__ = (0, 1, 2)
 __version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
@@ -74,6 +74,9 @@ import pelix.http as http
 HTTP_SERVICE_COMPONENT_FACTORY = "pelix.http.service.basic.factory"
 """ Name of the HTTP service component factory """
 
+HTTP_SERVICE_EXTRA = "http.extra"
+""" HTTP service extra properties (dictionary) """
+
 # ------------------------------------------------------------------------------
 
 class _HTTPServletRequest(http.AbstractHTTPServletRequest):
@@ -371,6 +374,7 @@ class _HttpServerFamily(ThreadingMixIn, HTTPServer):
 @Requires("_servlets_services", http.HTTP_SERVLET, True, True)
 @Property("_address", http.HTTP_SERVICE_ADDRESS, "0.0.0.0")
 @Property("_port", http.HTTP_SERVICE_PORT, 8080)
+@Property('_extra', HTTP_SERVICE_EXTRA, None)
 @Property("_instance_name", constants.IPOPO_INSTANCE_NAME)
 @Property("_logger_name", "pelix.http.logger.name", "")
 @Property("_logger_level", "pelix.http.logger.level", None)
@@ -385,6 +389,7 @@ class HttpService(object):
         # Properties
         self._address = "0.0.0.0"
         self._port = 8080
+        self._extra = None
         self._instance_name = None
         self._logger_name = None
         self._logger_level = None
@@ -613,23 +618,42 @@ class HttpService(object):
             if path in self._servlets:
                 # Already registered path
                 if self._servlets[path][0] is servlet:
-                    # Nothing to do
+                    # Double-registration: Nothing to do
                     return True
 
                 else:
-                    raise ValueError("A servlet is already registered on {0}" \
-                                     .format(path))
+                    # Path is already taken by another servlet
+                    already_taken = True
+
+            else:
+                # Path is available
+                already_taken = False
 
             # Add server information in parameters
-            parameters['http.address'] = self._address
-            parameters['http.port'] = self._port
+            parameters[http.PARAM_ADDRESS] = self._address
+            parameters[http.PARAM_PORT] = self._port
+            parameters[http.PARAM_NAME] = self._instance_name
+            parameters[http.PARAM_EXTRA] = self._extra.copy()
 
-            # Call back the method
+            # The servlet might refuse to be bound to this server
+            if not self.__safe_callback(servlet, "accept_binding",
+                                        path, parameters):
+                # Server refused: stop right there
+                # => No need to raise the "already taken path" exception
+                return False
+
+            if already_taken:
+                # The path is already taken by another servlet
+                raise ValueError("A servlet is already registered on {0}" \
+                                 .format(path))
+
+            # Tell the servlet it can be bound to the path
             if self.__safe_callback(servlet, "bound_to", path, parameters):
                 # Store the servlet
                 self._servlets[path] = (servlet, parameters)
                 return True
 
+            # The servlet refused the binding
             return False
 
 
@@ -719,6 +743,10 @@ class HttpService(object):
             # Ensure we have an integer
             self._port = int(self._port)
 
+        # Normalize the extra properties
+        if not isinstance(self._extra, dict):
+            self._extra = {}
+
         # Set up the logger
         if self._logger_name is not None:
             if not self._logger:
