@@ -4,9 +4,9 @@
 Dependency-less LDAP filter parser for Python
 
 :author: Thomas Calmant
-:copyright: Copyright 2012, isandlaTech
+:copyright: Copyright 2013, isandlaTech
 :license: GPLv3
-:version: 0.3
+:version: 0.3.1
 :status: Alpha
 
 ..
@@ -32,19 +32,24 @@ import inspect
 
 # ------------------------------------------------------------------------------
 
-__version__ = (0, 3, 0)
+# Module version
+__version_info__ = (0, 3, 1)
+__version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
 __docformat__ = "restructuredtext en"
 
 # ------------------------------------------------------------------------------
 
-# Escape character
 ESCAPE_CHARACTER = '\\'
+""" The LDAP escape character: \\"""
 
-# Escaped characters (do not insert the ESCAPE CHARACTER here)
-# See http://www.ldapexplorer.com/en/manual/109010000-ldap-filter-syntax.htm)
+# Do not insert the ESCAPE CHARACTER in this list
 ESCAPED_CHARACTERS = "()&|=<>~*+#,;'\""
+"""
+The characters to escape in an LDAP string.
+See http://www.ldapexplorer.com/en/manual/109010000-ldap-filter-syntax.htm
+"""
 
 # ------------------------------------------------------------------------------
 
@@ -389,7 +394,6 @@ def unescape_LDAP(ldap_string):
         # No need to loop
         return ldap_string
 
-    i = 0
     escaped = False
     result = ""
 
