@@ -31,7 +31,7 @@ telnet or netcat.
 """
 
 # Module version
-__version_info__ = (0, 1, 0)
+__version_info__ = (0, 1, 1)
 __version__ = ".".join(map(str, __version_info__))
 
 # Documentation strings format
@@ -40,8 +40,8 @@ __docformat__ = "restructuredtext en"
 # ------------------------------------------------------------------------------
 
 from pelix.ipopo.decorators import ComponentFactory, Requires, Property, \
-    Validate, Invalidate
-from pelix.shell import SHELL_SERVICE_SPEC
+    Validate, Invalidate, Provides
+from pelix.shell import SHELL_SERVICE_SPEC, REMOTE_SHELL_SPEC
 
 # ------------------------------------------------------------------------------
 
@@ -263,6 +263,7 @@ def _create_server(shell, server_address, port):
 # ------------------------------------------------------------------------------
 
 @ComponentFactory("ipopo-remote-shell-factory")
+@Provides(REMOTE_SHELL_SPEC)
 @Property("_address", "pelix.shell.address", "localhost")
 @Property("_port", "pelix.shell.port", 9000)
 @Requires("_shell", SHELL_SERVICE_SPEC)
@@ -285,6 +286,15 @@ class IPopoRemoteShell(object):
         self._server_flag = None
 
 
+    def get_access(self):
+        """
+        Implementation of the remote shell specification
+        
+        :return: A (host, port) tuple
+        """
+        return (self._address, self._port)
+
+
     def get_banner(self):
         """
         Retrieves the shell banner
